[Scummvm-cvs-logs] SF.net SVN: scummvm: [27941] scummvm/trunk/engines/agi/graphics.cpp

buddha_ at users.sourceforge.net buddha_ at users.sourceforge.net
Fri Jul 6 18:50:44 CEST 2007


Revision: 27941
          http://scummvm.svn.sourceforge.net/scummvm/?rev=27941&view=rev
Author:   buddha_
Date:     2007-07-06 09:50:44 -0700 (Fri, 06 Jul 2007)

Log Message:
-----------
Added data for an Amiga-style busy mouse cursor (An hourglass). Not used yet though.

Modified Paths:
--------------
    scummvm/trunk/engines/agi/graphics.cpp

Modified: scummvm/trunk/engines/agi/graphics.cpp
===================================================================
--- scummvm/trunk/engines/agi/graphics.cpp	2007-07-06 13:51:05 UTC (rev 27940)
+++ scummvm/trunk/engines/agi/graphics.cpp	2007-07-06 16:50:44 UTC (rev 27941)
@@ -768,7 +768,8 @@
 };
 
 /**
  * RGBA-palette for the Amiga-style arrow cursor.
  */
 static const byte amigaMouseCursorPalette[] = {
 	0x00, 0x00, 0x00,	0x00, // Black
@@ -776,6 +777,32 @@
 	0xFF, 0xCF, 0xAD,	0x00  // Light red
 };
 
+/**
+ * An Amiga-style busy cursor showing an hourglass (13x16).
+ * 0 = Transparent.
+ * 1 = Black     (#000000 in 24-bit RGB).
+ * 2 = Red       (#DE2021 in 24-bit RGB).
+ * 3 = Light red (#FFCFAD in 24-bit RGB).
+ */
+static const byte busyAmigaMouseCursor[] = {
+	1,1,1,1,1,1,1,1,1,1,1,1,1,
+	1,2,2,2,2,2,2,2,2,2,2,2,1,
+	1,2,2,2,2,2,2,2,2,2,2,2,1,
+	0,1,3,3,3,3,3,3,3,3,3,1,0,
+	0,0,1,3,3,3,3,3,3,3,1,0,0,
+	0,0,0,1,3,3,3,3,3,1,0,0,0,
+	0,0,0,0,1,3,3,3,1,0,0,0,0,
+	0,0,0,0,0,1,3,1,0,0,0,0,0,
+	0,0,0,0,0,1,3,1,0,0,0,0,0,
+	0,0,0,0,1,2,3,2,1,0,0,0,0,
+	0,0,0,1,2,2,3,2,2,1,0,0,0,
+	0,0,1,2,2,2,3,2,2,2,1,0,0,
+	0,1,2,2,2,3,3,3,2,2,2,1,0,
+	1,3,3,3,3,3,3,3,3,3,3,3,1,
+	1,3,3,3,3,3,3,3,3,3,3,3,1,
+	1,1,1,1,1,1,1,1,1,1,1,1,1
+};
+
 void GfxMgr::setCursor(bool amigaStyleCursor) {
 	if (!amigaStyleCursor) {
 		CursorMan.replaceCursorPalette(sciMouseCursorPalette, 1, ARRAYSIZE(sciMouseCursorPalette) / 4);
@@ -768,7 +768,8 @@
 
 /**
- * RGBA-palette for the Amiga-style arrow cursor.
+ * RGBA-palette for the Amiga-style arrow cursor
+ * and the Amiga-style busy cursor.
  */
 static const byte amigaMouseCursorPalette[] = {


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list